@@ -5,7 +5,7 @@
  *             packet encryption, packet authentication, and
  *             packet compression.
  *
- *  Copyright (C) 2002-2017 OpenVPN Technologies, Inc. <sales@openvpn.net>
+ *  Copyright (C) 2002-2018 OpenVPN Inc <sales@openvpn.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2
@@ -181,7 +181,7 @@ struct options
 
     /* enable forward compatibility for post-2.1 features */
     bool forward_compatible;
-    /* list of options that should be ignored even if unkown */
+    /* list of options that should be ignored even if unknown */
     const char **ignore_unknown_option;
 
     /* persist parms */
@@ -503,6 +503,7 @@ struct options
     const char *priv_key_file;
     const char *pkcs12_file;
     const char *cipher_list;
+    const char *tls_cert_profile;
     const char *ecdh_curve;
     const char *tls_verify;
     int verify_x509_type;
